pub enum Token {
Show 131 variants
Error,
PropertyExternal,
PropertyByRef,
PropertyConstant,
PropertySized,
KeywordProgram,
KeywordClass,
KeywordEndClass,
KeywordExtends,
KeywordImplements,
KeywordInterface,
KeywordEndInterface,
KeywordVarInput,
KeywordVarOutput,
KeywordVar,
KeywordVarConfig,
KeywordAbstract,
KeywordFinal,
KeywordMethod,
KeywordEndMethod,
KeywordSuper,
KeywordThis,
KeywordPropertyGet,
KeywordPropertySet,
KeywordEndProperty,
KeywordConstant,
KeywordRetain,
KeywordNonRetain,
KeywordVarTemp,
KeywordAccessPublic,
KeywordAccessPrivate,
KeywordAccessInternal,
KeywordAccessProtected,
KeywordOverride,
KeywordVarGlobal,
KeywordVarInOut,
KeywordVarExternal,
KeywordEndVar,
KeywordEndProgram,
KeywordFunction,
KeywordEndFunction,
KeywordFunctionBlock,
KeywordEndFunctionBlock,
KeywordType,
KeywordStruct,
KeywordEndType,
KeywordEndStruct,
KeywordActions,
KeywordAction,
KeywordEndAction,
KeywordEndActions,
KeywordColon,
KeywordSemicolon,
KeywordAssignment,
KeywordOutputAssignment,
KeywordReferenceAssignment,
KeywordParensOpen,
KeywordParensClose,
KeywordSquareParensOpen,
KeywordSquareParensClose,
KeywordComma,
KeywordDotDotDot,
KeywordDotDot,
KeywordDot,
KeywordIf,
KeywordThen,
KeywordElseIf,
KeywordElse,
KeywordEndIf,
KeywordFor,
KeywordTo,
KeywordBy,
KeywordDo,
KeywordEndFor,
KeywordWhile,
KeywordEndWhile,
KeywordRepeat,
KeywordUntil,
KeywordEndRepeat,
KeywordCase,
KeywordReturn,
KeywordExit,
KeywordContinue,
KeywordPointer,
KeywordFunctionPointer,
KeywordRef,
KeywordReferenceTo,
KeywordArray,
KeywordString,
KeywordWideString,
KeywordOf,
KeywordAt,
KeywordEndCase,
OperatorPlus,
OperatorMinus,
OperatorMultiplication,
OperatorExponent,
OperatorDivision,
OperatorEqual,
OperatorNotEqual,
OperatorLess,
OperatorGreater,
OperatorLessOrEqual,
OperatorGreaterOrEqual,
OperatorAmp,
OperatorDeref,
OperatorModulo,
OperatorAndThen,
OperatorAnd,
OperatorOrElse,
OperatorOr,
OperatorXor,
OperatorNot,
Identifier,
LiteralIntegerHex,
LiteralIntegerOct,
LiteralIntegerBin,
LiteralInteger,
LiteralNull,
LiteralTrue,
LiteralFalse,
LiteralDate,
LiteralDateAndTime,
LiteralTimeOfDay,
LiteralTime,
DirectAccess(DirectAccessType),
HardwareAccess((HardwareAccessType, DirectAccessType)),
LiteralString,
LiteralWideString,
TypeCastPrefix,
End,
}Variants
Error
PropertyExternal
PropertyByRef
PropertyConstant
PropertySized
KeywordProgram
KeywordClass
KeywordEndClass
KeywordExtends
KeywordImplements
KeywordInterface
KeywordEndInterface
KeywordVarInput
KeywordVarOutput
KeywordVar
KeywordVarConfig
KeywordAbstract
KeywordFinal
KeywordMethod
KeywordEndMethod
KeywordSuper
KeywordThis
KeywordPropertyGet
KeywordPropertySet
KeywordEndProperty
KeywordConstant
KeywordRetain
KeywordNonRetain
KeywordVarTemp
KeywordAccessPublic
KeywordAccessPrivate
KeywordAccessInternal
KeywordAccessProtected
KeywordOverride
KeywordVarGlobal
KeywordVarInOut
KeywordVarExternal
KeywordEndVar
KeywordEndProgram
KeywordFunction
KeywordEndFunction
KeywordFunctionBlock
KeywordEndFunctionBlock
KeywordType
KeywordStruct
KeywordEndType
KeywordEndStruct
KeywordActions
KeywordAction
KeywordEndAction
KeywordEndActions
KeywordColon
KeywordSemicolon
KeywordAssignment
KeywordOutputAssignment
KeywordReferenceAssignment
KeywordParensOpen
KeywordParensClose
KeywordSquareParensOpen
KeywordSquareParensClose
KeywordComma
KeywordDotDotDot
KeywordDotDot
KeywordDot
KeywordIf
KeywordThen
KeywordElseIf
KeywordElse
KeywordEndIf
KeywordFor
KeywordTo
KeywordBy
KeywordDo
KeywordEndFor
KeywordWhile
KeywordEndWhile
KeywordRepeat
KeywordUntil
KeywordEndRepeat
KeywordCase
KeywordReturn
KeywordExit
KeywordContinue
KeywordPointer
KeywordFunctionPointer
KeywordRef
KeywordReferenceTo
KeywordArray
KeywordString
KeywordWideString
KeywordOf
KeywordAt
KeywordEndCase
OperatorPlus
OperatorMinus
OperatorMultiplication
OperatorExponent
OperatorDivision
OperatorEqual
OperatorNotEqual
OperatorLess
OperatorGreater
OperatorLessOrEqual
OperatorGreaterOrEqual
OperatorAmp
OperatorDeref
OperatorModulo
OperatorAndThen
OperatorAnd
OperatorOrElse
OperatorOr
OperatorXor
OperatorNot
Identifier
LiteralIntegerHex
LiteralIntegerOct
LiteralIntegerBin
LiteralInteger
LiteralNull
LiteralTrue
LiteralFalse
LiteralDate
LiteralDateAndTime
LiteralTimeOfDay
LiteralTime
DirectAccess(DirectAccessType)
HardwareAccess((HardwareAccessType, DirectAccessType))
LiteralString
LiteralWideString
TypeCastPrefix
End
Implementations
Sourceimpl Token
impl Token
Sourcepub fn is_identifier_like(&self) -> bool
pub fn is_identifier_like(&self) -> bool
Returns true if the current token can be used where an identifier is expected.
PROPERTY_GET and PROPERTY_SET are soft keywords: they are parsed as property accessors in
property declarations, but may still be used as identifiers elsewhere.
Sourcepub fn classes(&self) -> &'static [TokenClass]
pub fn classes(&self) -> &'static [TokenClass]
Linguistic classification of this token, returned as a slice so a token can carry more than one class. Empty when nothing currently classifies the token.